# Authors

**BioPsyKit** was developed at Friedrich-Alexander-Universität Erlangen-Nürnberg (FAU) as a collaboration between the
Machine Learning and Data Analytics Lab (MaD Lab) and the Chair of Health Psychology.

## Authors
* Robert Richer <robert.richer@fau.de>
* Arne Küderle <arne.kuederle@fau.de>

## Contributors
* Rebecca Lennartz <rebecca.lennartz@fau.de>
* Daniel Krauß <daniel.k.krauss@fau.de>
* Victoria Müller <victoria.m.mueller@fau.de>
* Martin Ullrich <martin.ullrich@fau.de>
* Janis Zenkner <janis.zenkner@fau.de>

## Contact
Robert Richer <robert.richer@fau.de>
